# Copyright 2014 Canonical Ltd.  This software is licensed under the
# GNU General Public License version 3 (see the file LICENSE).
import mock
import os
from unittest import TestCase

from mojo.phase import DeployerPhase
from mojo.tests.utils import MojoTestCaseMixin


class DeployerPhaseTestCase(TestCase, MojoTestCaseMixin):

    def get_deployer_command_for_run(self, phase, workspace, stage='staging'):
        """Return the deployer command executed when the phase runs."""
        # XXX: It'd be nicer to stub mojo.utils.subprocess.Popen
        # but bicommand makes that quite complicated.
        with mock.patch('mojo.phase.bicommand') as mock_bicommand:
            mock_bicommand.return_value = (0, 'fake-output')

            phase.run('unused', workspace, 'trusty', stage)

            return mock_bicommand.call_args[0][0]

    def test_multiple_configs_rendered_for_deployer(self):
        phase = DeployerPhase(config='services.cfg')
        workspace = self.create_workspace()
        self.create_spec(
            path=workspace.spec_dir,
            configs=['staging/services.cfg', 'services.cfg'],
            stage='staging')

        command = self.get_deployer_command_for_run(phase, workspace)

        # Verify that the configs were both rendered.
        self.assertTrue(os.path.exists(
            '{}/services.cfg'.format(workspace.repo_dir)))
        self.assertTrue(os.path.exists(
            '{}/staging/services.cfg'.format(workspace.repo_dir)))
        # Verify that the configs were included in the deployer command.
        expected_configs = (
            '-c {configs_dir}/services.cfg '
            '-c {configs_dir}/staging/services.cfg'.format(
                configs_dir=workspace.repo_dir))
        self.assertIn(expected_configs, command)
