# Copyright 2014 Canonical Ltd.  This software is licensed under the
# GNU General Public License version 3 (see the file LICENSE).
import os
from shutil import rmtree
from tempfile import mkdtemp

import mojo
from test_bzr import (
    create_unique_branch,
)


class MojoTestCaseMixin():

    def create_spec_dir(self, configs=None, stage=None, path=None,
                        manifests=None):
        """Return a tmp dir initialised as a spec branch with configs."""
        if path is None:
            path = mkdtemp()
            self.addCleanup(rmtree, path)
        configs = configs or []
        if stage is not None:
            os.makedirs(os.path.join(path, stage))
        create_unique_branch(path, configs, manifests)
        return path

    def create_spec(self, configs=None, stage=None, path=None,
                    manifests=None):
        spec_dir = self.create_spec_dir(configs=configs, stage=stage,
                                        path=path, manifests=manifests)
        return mojo.Spec(spec_dir)

    def create_workspace(self, name="workspace"):
        workspace_dir = mkdtemp()
        self.addCleanup(rmtree, workspace_dir)
        workspace = mojo.Workspace(name, workspace_dir)
        workspace.prepare()
        os.mkdir(workspace.repo_dir)
        return workspace
